"""Pydantic schemas for Twitch Helix API."""

from .base import DateRange, Pagination, TwitchBaseModel, TwitchResponse

# Re-export all schemas for convenience
from . import (
    ads,
    analytics,
    bits,
    channel_points,
    channels,
    charity,
    chat,
    clips,
    eventsub,
    games,
    goals,
    guest_star,
    hype_train,
    moderation,
    polls,
    predictions,
    raids,
    schedule,
    search,
    streams,
    subscriptions,
    teams,
    users,
    videos,
    whispers,
)

__all__ = [
    "TwitchBaseModel",
    "TwitchResponse",
    "Pagination",
    "DateRange",
    "ads",
    "analytics",
    "bits",
    "channel_points",
    "channels",
    "charity",
    "chat",
    "clips",
    "eventsub",
    "games",
    "goals",
    "guest_star",
    "hype_train",
    "moderation",
    "polls",
    "predictions",
    "raids",
    "schedule",
    "search",
    "streams",
    "subscriptions",
    "teams",
    "users",
    "videos",
    "whispers",
]
